
/* Chrysalide - Outil d'analyse de fichiers binaires
 * hub.c - groupe de décompositions de motif de recherche en atomes assemblés
 *
 * Copyright (C) 2023 Cyrille Bagard
 *
 *  This file is part of Chrysalide.
 *
 *  Chrysalide is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Chrysalide is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with Foobar.  If not, see <http://www.gnu.org/licenses/>.
 */


#include "hub.h"


#include "hub-int.h"



/* ------------------------ DECOMPOSITION DE MOTIF RECHERCHE ------------------------ */


/* Initialise la classe des groupes de décompositions. */
static void g_scan_token_node_hub_class_init(GScanTokenNodeHubClass *klass);

/* Initialise une instance de groupe de décompositions. */
static void g_scan_token_node_hub_init(GScanTokenNodeHub *);

/* Supprime toutes les références externes. */
static void g_scan_token_node_hub_dispose(GScanTokenNodeHub *);

/* Procède à la libération totale de la mémoire. */
static void g_scan_token_node_hub_finalize(GScanTokenNodeHub *);



/* --------------------- IMPLEMENTATION DES FONCTIONS DE CLASSE --------------------- */





/* ---------------------------------------------------------------------------------- */
/*                          DECOMPOSITION DE MOTIF RECHERCHE                          */
/* ---------------------------------------------------------------------------------- */


/* Indique le type défini pour un groupe de décompositions de motif d'octets à rechercher. */
G_DEFINE_TYPE(GScanTokenNodeHub, g_scan_token_node_hub, G_TYPE_SCAN_TOKEN_NODE);


/******************************************************************************
*                                                                             *
*  Paramètres  : klass = classe à initialiser.                                *
*                                                                             *
*  Description : Initialise la classe des groupes de décompositions.          *
*                                                                             *
*  Retour      : -                                                            *
*                                                                             *
*  Remarques   : -                                                            *
*                                                                             *
******************************************************************************/

static void g_scan_token_node_hub_class_init(GScanTokenNodeHubClass *klass)
{
    GObjectClass *object;                   /* Autre version de la classe  */

    object = G_OBJECT_CLASS(klass);

    object->dispose = (GObjectFinalizeFunc/* ! */)g_scan_token_node_hub_dispose;
    object->finalize = (GObjectFinalizeFunc)g_scan_token_node_hub_finalize;

}


/******************************************************************************
*                                                                             *
*  Paramètres  : hub = instance à initialiser.                                *
*                                                                             *
*  Description : Initialise une instance de groupe de décompositions.         *
*                                                                             *
*  Retour      : -                                                            *
*                                                                             *
*  Remarques   : -                                                            *
*                                                                             *
******************************************************************************/

static void g_scan_token_node_hub_init(GScanTokenNodeHub *hub)
{

}


/******************************************************************************
*                                                                             *
*  Paramètres  : hub = instance d'objet GLib à traiter.                       *
*                                                                             *
*  Description : Supprime toutes les références externes.                     *
*                                                                             *
*  Retour      : -                                                            *
*                                                                             *
*  Remarques   : -                                                            *
*                                                                             *
******************************************************************************/

static void g_scan_token_node_hub_dispose(GScanTokenNodeHub *hub)
{
    G_OBJECT_CLASS(g_scan_token_node_hub_parent_class)->dispose(G_OBJECT(hub));

}


/******************************************************************************
*                                                                             *
*  Paramètres  : hub = instance d'objet GLib à traiter.                       *
*                                                                             *
*  Description : Procède à la libération totale de la mémoire.                *
*                                                                             *
*  Retour      : -                                                            *
*                                                                             *
*  Remarques   : -                                                            *
*                                                                             *
******************************************************************************/

static void g_scan_token_node_hub_finalize(GScanTokenNodeHub *hub)
{
    G_OBJECT_CLASS(g_scan_token_node_hub_parent_class)->finalize(G_OBJECT(hub));

}



/* ---------------------------------------------------------------------------------- */
/*                       IMPLEMENTATION DES FONCTIONS DE CLASSE                       */
/* ---------------------------------------------------------------------------------- */




